@@ -15,7 +15,7 @@ jomo1cat <-
           Yi[j,h:(h+Y_numcat[i]-2)]=NA
         }
       } 
-      h=h+Y_numcat[i]
+      h=h+Y_numcat[i]-1
     }
     imp=matrix(0,nrow(Y)*(nimp+1),ncol(Y)+ncol(X)+2)
     imp[1:nrow(Y),1:ncol(Y)]=Y
